@@ -23,9 +23,11 @@ library(lognorm)
 if (!require(ggplot2) || !require(dplyr) || !require(tidyr) || !require(purrr) ||
     !require(mvtnorm)
     ) {
-	print(paste("To generate this vignette, ggplot2, dplyr, tidyr, purr,"
-	            ," and mvtnorm are required."))
-	exit(0)
+  msg = paste0("To generate this vignette, ggplot2, dplyr, tidyr, purrr,"
+	            ," and mvtnorm are required.")
+  print(msg)
+	warning(msg)
+  knitr::knit_exit()
 }
 themeTw <- theme_bw(base_size = 10) + 
   theme(axis.title = element_text(size = 9))
@@ -34,7 +36,7 @@ themeTw <- theme_bw(base_size = 10) +
 nObs <- 100; nRep <- 10000
 #nObs <- 1000; nRep <- 100
 xTrue <- rep(10, nObs)
-sigmaStar <- rep(1.7, nObs) # multiplicative stddev of 1.2
+sigmaStar <- rep(1.7, nObs) # multiplicative stddev 
 theta <- getParmsLognormForExpval(xTrue, sigmaStar)
 # generate observations with correlated errors
 acf1 <- c(0.4,0.1)
